@@ -42,8 +42,6 @@ ScreenCastWidget::ScreenCastWidget(QWidget *parent)
             widgetItem->setText(i18n("Manufacturer: %1\nModel: %2", it.value().manufacturer(), it.value().model()));
         }
     }
-
-    itemAt(0, 0)->setSelected(true);
 }
 
 ScreenCastWidget::~ScreenCastWidget()
@@ -54,7 +52,8 @@ QList<quint32> ScreenCastWidget::selectedScreens() const
 {
     QList<quint32> selectedScreens;
 
-    for (QListWidgetItem *item : selectedItems()) {
+    const auto selectedItems = this->selectedItems();
+    for (QListWidgetItem *item : selectedItems) {
         selectedScreens << item->data(Qt::UserRole).toUInt();
     }
 
